﻿using System;
using System.IO;
using System.Windows.Forms;
using System.Xml.Serialization;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 이벤트를 설정한다.

            this.serializeButton.Click   += serializeButton_Click;
            this.deserializeButton.Click += deserializeButton_Click;

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 직렬화 버튼 클릭시 처리하기 - serializeButton_Click(sender, e)

        /// <summary>
        /// 직렬화 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void serializeButton_Click(object sender, EventArgs e)
        {
            Person person = new Person
            (
                this.firstNameTextBox.Text,
                this.lastNameTextBox.Text,
                this.streetTextBox.Text,
                this.cityTextBox.Text,
                this.stateTextBox.Text,
                this.zipTextBox.Text
            );

            XmlSerializer serializer = new XmlSerializer(typeof(Person));

            using(StringWriter writer = new StringWriter())
            {
                serializer.Serialize(writer, person);

                this.xmlTextBox.Text = writer.ToString();
            }

            this.firstNameTextBox.Clear();
            this.lastNameTextBox.Clear();
            this.streetTextBox.Clear();
            this.cityTextBox.Clear();
            this.stateTextBox.Clear();
            this.zipTextBox.Clear();
        }

        #endregion
        #region 역직렬화 버튼 클릭시 처리하기 - deserializeButton_Click(sender, e)

        /// <summary>
        /// 역직렬화 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void deserializeButton_Click(object sender, EventArgs e)
        {
            XmlSerializer serializer = new XmlSerializer(typeof(Person));

            using(StringReader reader = new StringReader(this.xmlTextBox.Text))
            {
                Person person = (Person)(serializer.Deserialize(reader));

                this.firstNameTextBox.Text = person.FirstName;
                this.lastNameTextBox.Text  = person.LastName;
                this.streetTextBox.Text    = person.Street;
                this.cityTextBox.Text      = person.City;
                this.stateTextBox.Text     = person.Street;
                this.zipTextBox.Text       = person.Zip;
            }

            this.xmlTextBox.Clear();
        }

        #endregion
    }
}